@@ -86,7 +86,7 @@ clear3d     <- function(type = c("shapes", "bboxdeco", "material"),
 rgl.material.names <- c("color", "alpha", "lit", "ambient", "specular",
     "emission", "shininess", "smooth", "front", "back", "size", 
     "lwd", "fog", "point_antialias", "line_antialias",
-    "texture", "textype", "texmipmap",
+    "texture", "textype", "texmode", "texmipmap",
     "texminfilter", "texmagfilter", "texenvmap",
     "depth_mask", "depth_test", "isTransparent",
     "polygon_offset", "margin", "floating", "tag",
@@ -94,6 +94,37 @@ rgl.material.names <- c("color", "alpha", "lit", "ambient", "specular",
 
 rgl.material.readonly <- "isTransparent"
 
+# Warn about putting a texture on a black surface, but only
+# if the surface is black because that's the default.
+
+warnBlackTexture <- function(...,
+                             defaults = material3d(),
+                             color = col, col = "missing",
+                             texture = defaults$texture,
+                             texmode = defaults$texmode) {
+  if (!is.null(texture)) {
+    if (length(color) == 1 &&
+      !is.na(color) &&
+      color == "missing" &&
+      !is.na(texmode) && 
+      texmode == "modulate" &&
+      isTRUE(getOption("rgl.warnBlackTexture", TRUE)) &&
+      length(defaults$color) &&
+      !is.na(defaults$color[1]) &&
+      defaults$color[1] %in% c("#000000", "black"))
+      warning("Texture will be invisible on black surface", call. = FALSE) 
+  }
+}
+
+# Attach the expression for the source of a texture if
+# it is not already there
+
+addTextureSource <- function(texture, ...) {
+  if (!is.null(texture) && is.null(attr(texture, "src")))
+    attr(texture, "src") <- substitute(texture)
+  texture
+}
+
 # This function expands a list of arguments by putting
 # all entries from Params (i.e. the current settings by default)
 # in place for any entries that are not listed.  
@@ -102,6 +133,12 @@ rgl.material.readonly <- "isTransparent"
 .fixMaterialArgs <- function(..., Params = material3d(), col) {
    f <- function(...) list(...)
    dots <- list(...)
+   if (!is.null(dots$texture)) {
+     warnBlackTexture(...,  
+       col = if (missing(col)) "missing" else col,
+       defaults = Params)
+     dots$texture <- addTextureSource(...)
+   }
    if (!missing(col)) 
      Params$color <- col
    formals(f) <- c(Params, formals(f))
@@ -110,7 +147,7 @@ rgl.material.readonly <- "isTransparent"
    names <- lapply(names, as.name)
    b <- as.list(body(f))
    body(f) <- as.call(c(b[1], names, b[-1]))
-   f(...)
+   do.call(f, dots)
 } 
 
 # This one just expands the argument names to match the
@@ -163,6 +200,8 @@ material3d  <- function(..., id = NULL) {
   }
   value <- rgl.getmaterial(id = id)[argnames]
   if (length(args)) {
+    save <- options(rgl.warnBlackTexture = FALSE)
+    on.exit(options(save))
     args <- do.call(".fixMaterialArgs", args)
     do.call("rgl.material0", args)
     return(invisible(value))
@@ -315,6 +354,7 @@ view3d      <- function(theta = 0.0, phi = 15.0,
   
   if (! ret$success)
     stop("'rgl_viewpoint' failed")
+  lowlevel()
 }
 
 bbox3d	    <- function(xat = NULL, 
