@@ -81,7 +81,7 @@ float& Vec3::operator [] (int i) {
   case 1: return y;
   case 2: return z;
   }
-  error("out of bounds");
+  Rf_error("out of bounds");
 }
 
 Vec3 Vec3::scale(const Vec3& op2) const
@@ -174,7 +174,7 @@ float& Vec4::operator [] (int i) {
     case 2: return z;
     case 3: return w;
   }
-  error("out of bounds");
+  Rf_error("out of bounds");
 }
 
 
