@@ -126,7 +126,7 @@ bool Subscene::add(SceneNode* node)
       {
 	Subscene* subscene = static_cast<Subscene*>(node);
 	if (subscene->parent)
-	  error("Subscene %d is already a child of subscene %d.", subscene->getObjID(),
+	  Rf_error("Subscene %d is already a child of subscene %d.", subscene->getObjID(),
 	        subscene->parent->getObjID());
 	addSubscene(subscene);
 	success = true;
@@ -365,13 +365,11 @@ void Subscene::getAttribute(SceneNode* subscene, AttribID attrib, int first, int
   }
 }
 
-String Subscene::getTextAttribute(SceneNode* subscene, AttribID attrib, int index)
+std::string Subscene::getTextAttribute(SceneNode* subscene, AttribID attrib, int index)
 {
   int n = getAttributeCount(subscene, attrib);
   if (index < n && attrib == TYPES) {
-    char* buffer = R_alloc(20, 1);    
-    shapes[index]->getTypeName(buffer, 20);
-    return String(static_cast<int>(strlen(buffer)), buffer);
+    return shapes[index]->getTypeName();
   } else
     return SceneNode::getTextAttribute(subscene, attrib, index);
 }
@@ -441,16 +439,12 @@ int Subscene::get_id_count(TypeID type, bool recursive)
     
 int Subscene::get_ids(TypeID type, int* ids, char** types, bool recursive)
 {
-  char buffer[20];
   int count = 0;
   switch(type) {
   case SHAPE: 
     for (std::vector<Shape*>::iterator i = shapes.begin(); i != shapes.end() ; ++ i ) {
       *ids++ = (*i)->getObjID();
-      buffer[19] = 0;
-      (*i)->getTypeName(buffer, 20);
-      *types = R_alloc(strlen(buffer)+1, 1);
-      strcpy(*types, buffer);
+      *types = copyStringToR((*i)->getTypeName());
       types++;
       count++;
     }
@@ -568,7 +562,7 @@ UserViewpoint* Subscene::getUserViewpoint()
   if (userviewpoint && do_projection > EMBED_INHERIT)
     return userviewpoint;
   else if (parent) return parent->getUserViewpoint();
-  else error("must have a user viewpoint");
+  else Rf_error("must have a user viewpoint");
 }
 
 ModelViewpoint* Subscene::getModelViewpoint()
@@ -576,7 +570,7 @@ ModelViewpoint* Subscene::getModelViewpoint()
   if (modelviewpoint && do_model > EMBED_INHERIT)
     return modelviewpoint;
   else if (parent) return parent->getModelViewpoint();
-  else error("must have a model viewpoint");
+  else Rf_error("must have a model viewpoint");
 }
 
 void Subscene::update(RenderContext* renderContext)
@@ -1070,7 +1064,7 @@ Embedding Subscene::getEmbedding(Embedded which)
     case EM_PROJECTION:    return do_projection;
     case EM_MODEL:         return do_model;
     case EM_MOUSEHANDLERS: return do_mouseHandlers;
-    default: error("Bad embedding requested");
+    default: Rf_error("Bad embedding requested");
   }
 }
 
